@@ -2,7 +2,7 @@
 
 """
 lswifi.constants
-~~~~~~~~~~~~~~~
+~~~~~~~~~~~~~~~~
 
 define app constant values
 """
@@ -53,7 +53,7 @@ INTERWORKING_NETWORK_TYPE = {
     2: "Chargeable public network",
     3: "Free public network",
     4: "Personal device network",
-    5: "Reserved",
+    5: "Emergency services only network",
     6: "Reserved",
     7: "Reserved",
     8: "Reserved",
@@ -117,7 +117,7 @@ IE_DICT = {
     133: "Cisco CCX1 CKIP + Device Name",
     148: "DMG Capabilities",
     149: "Cisco Unknown 95",
-    150: "Cisco Vendor Specific",
+    150: "Cisco",
     151: "DMG Operation",
     158: "Multi-band",
     159: "ADDBA Extension",
@@ -125,13 +125,14 @@ IE_DICT = {
     191: "VHT Capabilities",
     192: "VHT Operation",
     193: "Extended BSS Load",
-    195: "VHT Tx Power Envelope",
+    195: "Tx Power Envelope",
     197: "AID",
     198: "Quiet Channel",
     201: "Reduced Neighbor Report",
     202: "TVHT Operation",
     216: "TWT",
-    221: "Vendor Specific",
+    221: "Vendor",
+    244: "RSN eXtension",
     255: "Extension",
 }
 
@@ -299,4 +300,63 @@ _20MHZ_CHANNEL_LIST = {
     "4945": "189",
     "4960": "192",
     "4980": "196",
+    "5955": "1",
+    "5975": "5",
+    "5995": "9",
+    "6015": "13",
+    "6035": "17",
+    "6055": "21",
+    "6075": "25",
+    "6095": "29",
+    "6115": "33",
+    "6135": "37",
+    "6155": "41",
+    "6175": "45",
+    "6195": "49",
+    "6215": "53",
+    "6235": "57",
+    "6255": "61",
+    "6275": "65",
+    "6295": "69",
+    "6315": "73",
+    "6335": "77",
+    "6355": "81",
+    "6375": "85",
+    "6395": "89",
+    "6415": "93",
+    "6435": "97",
+    "6455": "101",
+    "6475": "105",
+    "6495": "109",
+    "6515": "113",
+    "6535": "117",
+    "6555": "121",
+    "6575": "125",
+    "6595": "129",
+    "6615": "133",
+    "6635": "137",
+    "6655": "141",
+    "6675": "145",
+    "6695": "149",
+    "6715": "153",
+    "6735": "157",
+    "6755": "161",
+    "6775": "165",
+    "6795": "169",
+    "6815": "173",
+    "6835": "177",
+    "6855": "181",
+    "6875": "185",
+    "6895": "189",
+    "6915": "193",
+    "6935": "197",
+    "6955": "201",
+    "6975": "205",
+    "6995": "209",
+    "7015": "213",
+    "7035": "217",
+    "7055": "221",
+    "7075": "225",
+    "7095": "229",
+    "7115": "233",
 }
