@@ -23,10 +23,16 @@ from .__version__ import __title__
 from .client import Client, get_interface_info
 from .constants import APNAMEJSONFILE
 from .elements import WirelessNetworkBss
-from .helpers import (Base64Encoder, format_bytes_as_hex,
-                      generate_pretty_separator, get_attr_max_len,
-                      is_five_band, is_six_band, is_two_four_band,
-                      strip_mac_address_format)
+from .helpers import (
+    Base64Encoder,
+    format_bytes_as_hex,
+    generate_pretty_separator,
+    get_attr_max_len,
+    is_five_band,
+    is_six_band,
+    is_two_four_band,
+    strip_mac_address_format,
+)
 from .schemas.out import *
 
 
